@@ -249,10 +249,11 @@ class PackageRegistry(Enum):
         assert pkg is not None, f"{self.value.pkg_name} is not found."
         local_version = getattr(pkg, "__version__")
         if version.parse(local_version) < version.parse(latest_version):
+            print(f"{self.value.name} package update available.")
             print(
-                f"{self.value.name} package update available. Your version is {local_version}. "
-                f"New version is {latest_version}."
+                f"Your version is {local_version}. Latest version is {latest_version}."
             )
+            print("Visit boulder.q-ctrl.com/changelog for the latest product updates.")
 
 
 def _get_latest_version(url) -> str:
